<?php
require_once( 'common/includes/class.toplist.php' );

class pPilotDetail extends pageAssembly
{
	private $viewList = array();
	private $klist = null;
	private $llist = null;
	private $menuOptions = array();

	// TODO: Make these private and add access functions for mods to use.
	public $scl_id = false;
	public $plt_id = false;
	public $page = null;

	//! Construct the Pilot Details object.

	/** Set up the basic variables of the class and add the functions to the
	 *  build queue.
	 */
	function __construct()
	{
		parent::__construct();

		$this->queue("start");
		$this->queue("statSetup");
		$this->queue("stats");
		$this->queue("medalBox");
		$this->queue("summaryTable");
		$this->queue("killList");
	}

	//! Reset the assembly object to prepare for creating the context.
	function context()
	{
		parent::__construct();
		$this->queue("menuSetup");
		$this->queue("menu");
		$this->queue("points");
	}

	//! Start constructing the page.

	/*! Prepare all the shared variables such as dates and check alliance ID.
	 *
	 */
	function start()
	{
		$this->page = new Page();

		$this->plt_id = (int)edkURI::getArg('plt_id');
		if (!$this->plt_id) {
			$this->plt_external_id = (int)edkURI::getArg('plt_ext_id');
			if (!$this->plt_external_id) {
				$id = (int)edkURI::getArg('id', 1);
				// Arbitrary number bigger than we expect to reach locally
				if ($id > 1000000) {
					$this->plt_external_id = $id;
				} else {
					$this->plt_id = $id;
				}
			}
		}

		$this->view = preg_replace('/[^a-zA-Z0-9_-]/','', edkURI::getArg('view', 2));
		if($this->view) {
			$this->page->addHeader('<meta name="robots" content="noindex, nofollow" />');
		}

		if(!$this->plt_id)
		{
			if($this->plt_external_id)
			{
				$this->pilot = new Pilot(0, $this->plt_external_id);
				$this->plt_id = $this->pilot->getID();
			}
			elseif(PILOT_ID)
			{
				$this->plt_id = PILOT_ID;
				$this->pilot = new Pilot(PILOT_ID);
			}
			else
			{
				$html = 'That pilot doesn\'t exist.';
				$this->page->generate($html);
				exit;
			}

		}
		else $this->pilot = new Pilot($this->plt_id);
		
		
		// initialize medal box vars
		$this->rank = array();
		$this->show_options = array();
		$this->titles = array();
		$this->medals = array();
		$this->shipbadges = array();
		$this->weaponbadges = array();
		$this->rps = 0;
		$this->bonus_rps = 0;
		$this->base_rps = 0;
		$this->malus_rps = 0;
		$this->rank_limit = 0;
		
		// check options for what should be displayed
		$this->show_options = config::get( 'rankmod_show' );
		// load custom rank titles
		$this->titles = config::get( 'rankmod_titles' );
		
		// load rank data
		$this->rank = getPilotRank( $this->plt_id, $points, $this->medals, $this->shipbadges, $this->weaponbadges, $this->base_rps, $this->bonus_rps, $this->rps, $this->malus_rps );
		
		// set maximum rank level
		$this->rank_limit = count( $this->titles );
		
		// show current rank in page title
		$this->page->setTitle( $this->titles[$this->rank]['abbr'].' '.$this->pilot->getName() );

		if (!$this->pilot->exists())
		{
			$html = 'That pilot doesn\'t exist.';
			$this->page->generate($html);
			exit;
		}
		$this->corp = $this->pilot->getCorp();
		$this->alliance = $this->corp->getAlliance();
		
	}
	//! Set up the stats used by stats and summaryTable functions.
	function statSetup()
	{
			$this->klist = new KillList();
			$this->llist = new KillList();
			$this->klist->addInvolvedPilot($this->pilot);
			$this->llist->addVictimPilot($this->pilot);
			$this->klist->getAllKills();
			$this->llist->getAllKills();
			$this->points = $this->klist->getPoints();
			$this->lpoints = $this->llist->getPoints();
			if(!isset($this->kill_summary))
			{
				$this->summary = new KillSummaryTable($this->klist, $this->llist);
				if ($this->view == "ships_weapons") $this->summary->setFilter(false);
			}
	}
	//! Build the summary table showing all kills and losses for this pilot.
	function summaryTable()
	{
		return $this->summary->generate();
	}
	
	//! Show the overall statistics for this alliance.
	function stats()
	{
		global $smarty;
		$smarty->assign( 'portrait_URL',$this->pilot->getPortraitURL(128));
		$smarty->assign( 'corp_id',$this->corp->getID());
		$smarty->assign( 'corp_name',$this->corp->getName());
		$smarty->assign( 'all_name',$this->alliance->getName());
		$smarty->assign( 'all_id',$this->alliance->getID());
		$smarty->assign( 'klist_count',$this->klist->getCount());
		$smarty->assign( 'klist_real_count',$this->klist->getRealCount());
		$smarty->assign( 'llist_count',$this->llist->getCount());
		$smarty->assign( 'klist_isk_B',round($this->klist->getISK()/1000000000,2));
		$smarty->assign( 'llist_isk_B',round($this->llist->getISK()/1000000000,2));

		//Pilot Efficiency Mod Begin (K Austin)

		if ($this->klist->getRealCount() == 0)
		{
			$pilot_survival = 100;
			$pilot_efficiency = 0;
		}
		else
		{
			if($this->klist->getRealCount() + $this->llist->getCount()) $pilot_survival = round($this->llist->getCount() / ($this->klist->getRealCount() + $this->llist->getCount()) * 100,2);
			else $pilot_survival = 0;
			if($this->klist->getISK() + $this->llist->getISK()) $pilot_efficiency = round(($this->klist->getISK() / ($this->klist->getISK() + $this->llist->getISK())) * 100,2);
			else $pilot_efficiency = 0;
		}

		$smarty->assign( 'pilot_survival', getPilotSurvivalComparison( $pilot_survival ) );
		$smarty->assign( 'pilot_efficiency', getPilotEfficiencyComparison( $pilot_efficiency ) );
		$smarty->assign( 'pilot_rank', $this->rank );
		$smarty->assign( 'pilot_titles', $this->titles );

		return $smarty->fetch( get_tpl( dirname(__FILE__) . '/' . 'pilot_detail_stats' ) );
	}
	
	//! Show the medals and awards for this pilot
	function medalBox()
	{
		global $smarty;
		
		//assign display vars
		if( strpos( config::get('rankmod_show'), 'medal' ) ) { $smarty->assign( 'medalcase_show_medals', 1 ); }
		if( strpos( config::get('rankmod_show'), 'rank' ) ) { $smarty->assign( 'medalcase_show_rank', 1 ); }
		if( strpos( config::get('rankmod_show'), 'badge' ) ) { $smarty->assign( 'medalcase_show_ribbons', 1 ); }
		if( strpos( config::get('rankmod_show'), 'points' ) ) { $smarty->assign( 'medalcase_show_rankpoints', 1 ); }
		if( strpos( config::get('rankmod_show'), 'progression' ) ) { $smarty->assign( 'medalcase_show_progression', 1 ); }
		if( strpos( config::get('rankmod_show'), 'nomeds' ) ) { $smarty->assign( 'medalcase_show_medalribbons', 1 ); }
		// assign values
		$smarty->assign( 'pilot_rank', $this->rank );
		$smarty->assign( 'pilot_ranklimit', $this->rank_limit );
		$smarty->assign( 'pilot_medals', $this->medals );
		$smarty->assign( 'pilot_shipbadges', $this->shipbadges );
		$smarty->assign( 'pilot_weaponbadges', $this->weaponbadges );
		// awardbadges are not calculated seperately in the ranks function, they are identical to the medals
		$smarty->assign( 'pilot_awardbadges', $this->medals );
		$smarty->assign( 'pilot_titles', $this->titles );
		$smarty->assign( 'pilot_rps', $this->rps );
		$smarty->assign( 'pilot_base_rps', $this->base_rps );
		$smarty->assign( 'pilot_bonus_rps', $this->bonus_rps );
		$smarty->assign( 'pilot_malus_rps', $this->malus_rps );

		return $smarty->fetch( get_tpl( dirname(__FILE__) . '/' . 'pilot_detail_medalbox' ) );
	}

	//! Build the killlists that are needed for the options selected.
	function killList()
	{
		global $smarty;
		if(isset($this->viewList[$this->view])) return call_user_func_array($this->viewList[$this->view], array(&$this));

		switch ($this->view)
		{
			case "kills":
				$list = new KillList();
				$list->setOrdered(true);
				$list->addInvolvedPilot($this->pilot);
				if ($this->scl_id) $list->addVictimShipClass($this->scl_id);
				$list->setPageSplit(config::get( 'killcount' ));
				$pagesplitter = new PageSplitter($list->getCount(), config::get( 'killcount' ));
				$table = new KillListTable($list);
				$table->setDayBreak(false);

				$smarty->assign( 'splitter',$pagesplitter->generate());
				$smarty->assign( 'kills', $table->generate());
				return $smarty->fetch(get_tpl( 'detail_kl_kills' ));

				break;
				
			case "losses":
				$list = new KillList();
				$list->setOrdered(true);
				$list->setPodsNoobships(config::get( 'podnoobs' ));
				$list->addVictimPilot($this->pilot);
				if ($this->scl_id) $list->addVictimShipClass($this->scl_id);
				$list->setPageSplit(config::get( 'killcount' ));
				$pagesplitter = new PageSplitter($list->getCount(), config::get( 'killcount' ));

				$table = new KillListTable($list);
				$table->setDayBreak(false);
				
				$smarty->assign( 'splitter',$pagesplitter->generate());
				$smarty->assign( 'losses', $table->generate());
				return $smarty->fetch(get_tpl( 'detail_kl_losses' ));
				
				break;
				
			case "ships_weapons":
				$shiplist = new TopShipList();
				$shiplist->addInvolvedPilot($this->pilot);
				$shiplisttable = new TopShipListTable($shiplist);
				$smarty->assign( 'ships', $shiplisttable->generate());

				$weaponlist = new TopWeaponList();
				$weaponlist->addInvolvedPilot($this->pilot);
				$weaponlisttable = new TopWeaponListTable($weaponlist);

				$smarty->assign( 'weapons', $weaponlisttable->generate());
				return $smarty->fetch(get_tpl( 'detail_kl_ships_weapons' ));

				break;
				
			case "rankmod_sig":
				$signatures = array();
				$dir = opendir( dirname( __FILE__ ) . '/signatures' );
				while( $line = readdir( $dir ) )
				{
				    if( file_exists( dirname( __FILE__ ) . '/signatures/' . $line . '/' . $line . '.php' ) )
				    {
				        $signatures[] = $line;
				    }
				}
				$smarty->assign( 'signatures', $signatures );
				$smarty->assign( 'kb_host', KB_HOST );
				$smarty->assign( 'pilot', intval( $this->plt_id ) );
				
				return $smarty->fetch( get_tpl( dirname( __FILE__ ) . '/' . 'rankmod_sig_list' ) );

				break;
				
			default:
				$list = new KillList();
				$list->setOrdered(true);
				if (config::get( 'comments_count' )) $list->setCountComments(true);
				if (config::get( 'killlist_involved' )) $list->setCountInvolved(true);
				$list->setLimit(10);
				$list->setPodsNoobships(config::get( 'podnoobs' ));
				$list->addInvolvedPilot($this->pilot);
				if ($this->scl_id) $list->addVictimShipClass($this->scl_id);

				$table = new KillListTable($list);
				$table->setDayBreak(false);
				$smarty->assign( 'kills', $table->generate());

				$list = new KillList();
				$list->setOrdered(true);
				if (config::get( 'comments_count' )) $list->setCountComments(true);
				if (config::get( 'killlist_involved' )) $list->setCountInvolved(true);
				$list->setLimit(10);
				$list->setPodsNoobships(config::get( 'podnoobs' ));
				$list->addVictimPilot($this->pilot);
				if ($this->scl_id) $list->addVictimShipClass($this->scl_id);

				$table = new KillListTable($list);
				$table->setDayBreak(false);
				$table->setDayBreak(false);
				$smarty->assign( 'losses', $table->generate());
				return $smarty->fetch(get_tpl( 'detail_kl_default' ));
				
				break;
		}
		return $html;
	}
	//! Set up the menu.

	//! Prepare all the base menu options.
	function menuSetup()
	{
		$this->addMenuItem("caption","Kills &amp; losses");
		$this->addMenuItem("link","Recent activity", "?a=pilot_detail&amp;plt_id=".$this->pilot->getID()."&amp;view=recent");
		$this->addMenuItem("link","Kills", "?a=pilot_detail&amp;plt_id=".$this->pilot->getID()."&amp;view=kills");
		$this->addMenuItem("link","Losses", "?a=pilot_detail&amp;plt_id=".$this->pilot->getID()."&amp;view=losses");
		$this->addMenuItem("caption","Statistics");
		$this->addMenuItem("link","Ships &amp; weapons", "?a=pilot_detail&amp;plt_id=".$this->pilot->getID()."&amp;view=ships_weapons");
		
		// rank_mod menu links
		if( strstr( config::get( "mods_active" ), 'rank_mod_OLD' ) )
		{
			$this->addMenuItem( "caption", "Rank" );
			$this->addMenuItem( "link", "Extended Signature", "?a=pilot_detail&plt_id=".$this->pilot->getID()."&view=rankmod_sig" );
		}
		return "";
	}
	//! Build the menu.

	//! Add all preset options to the menu.
	function menu()
	{
		$menubox = new box("Menu");
		$menubox->setIcon("menu-item.gif");
		foreach($this->menuOptions as $options)
		{
			if(isset($options[2]))
				$menubox->addOption($options[0],$options[1], $options[2]);
			else
				$menubox->addOption($options[0],$options[1]);
		}
		return $menubox->generate();
	}

	function points()
	{
		$html = '';
		if (config::get( 'kill_points' ) && !empty($this->points))
		{
			$scorebox = new Box("Kill points");
			$scorebox->addOption("points", $this->points);
			$html .= $scorebox->generate();
		}
		if (config::get( 'loss_points' ) && !empty($this->lpoints))
		{
			$scorebox = new Box("Loss points");
			$scorebox->addOption("points", $this->lpoints);
			$html .= $scorebox->generate();
		}
		if (config::get( 'total_points' ) && !empty($this->lpoints))
		{
			$scorebox = new Box("Total points");
			$scorebox->addOption("points", $this->points-$this->lpoints);
			$html .= $scorebox->generate();
		}
		return $html;
	}

	//! Add an item to the menu in standard box format.

	/*!
	 *  Only links need all 3 attributes
	 * \param type Types can be caption, img, link, points.
	 * \param name The name to display.
	 * \param url Only needed for URLs.
	 */
	function addMenuItem($type, $name, $url = '' )
	{
		$this->menuOptions[] = array($type, $name, $url);
	}

	//! Add a type of view to the options.

	/*!
	 * \param view The name of the view to recognise.
	 * \param callback The method to call when this view is used.
	 */
	function addView($view, $callback)
	{
		$this->viewList[$view] = $callback;
	}
}



$pilotDetail = new pPilotDetail();
event::call("pilotDetail_assembling", $pilotDetail);
$html = $pilotDetail->assemble();
$pilotDetail->page->setContent($html);

$pilotDetail->context();
event::call("pilotDetail_context_assembling", $pilotDetail);
$context = $pilotDetail->assemble();
$pilotDetail->page->addContext($context);

$pilotDetail->page->generate();