<?php
require_once( 'common/admin/admin_menu.php' );
require_once( 'common/includes/class.toplist.php' );
require_once( 'mods/rank_mod/settings_defines.php' );
require_once( 'mods/rank_mod/init.php' );

class RankModAdmin extends pageAssembly
{
	private $viewList = array();
	private $menuOptions = array();
	private $rank_ver = RANKMOD_VER;
	private $message = '';

	function __construct()
	{
		parent::__construct();

		$this->queue( "start" );
		$this->queue( "addViews" );
		$this->queue( "initConfigVars" );
		$this->queue( "checkViews" );
	}

	function context()
	{
		parent::__construct();
		$this->queue("menuSetup");
		$this->queue("menu");
	}

	function start()
	{
		$this->page = new Page( "Rank Mod Administration");

		$this->view = $_GET['view'];
		if( $this->view ) $this->page->addHeader( '<meta name="robots" content="noindex, nofollow" />' );

		$this->checkPreviousInstall();
	}

	function initConfigVars()
	{
		$this->rank_imageset = config::get( 'rankmod_imageset' ); // insignia image set
		$this->rank_titleset = config::get( 'rankmod_titleset' ); // title set
		$this->keep_title = config::get( 'rankmod_keep' ); // remember keep titles

		$this->rank_type = config::get( 'rankmod_rtype' ); // type of ranks (Enlisted, Officer, Enlisted + Officer)
		if( !( $this->rank_type ) ) { $this->rank_type = 'Enlisted + Officer'; }

		$this->rank_ef = config::get( 'rankmod_expfactor' ); // exp factor (1, 1.2, 1.5, 1.7, 2, 2.5)
		if( !( $this->rank_ef ) ) { $this->rank_ef = 1.2; }

		$this->rank_base = config::get( 'rankmod_expbase' ); // base value (amount of rank points to go to next level)
		if( !( $this->rank_base ) ) { $this->rank_base = 10; }

		$this->rank_conv = config::get( 'rankmod_convfactor' ); // conversion factor (every how much killpoints gets a rank point)
		if( !( $this->rank_conv ) ) { $this->rank_conv = 30; }

		$this->rank_badges = config::get( 'rankmod_badreqs' ); // requirements for badges level (elite, veteran, expert)
		if( !( $this->rank_badges ) ) { for( $i=1;$i<=8;$i++ ) $this->rank_badges[] = array( 100, 50, 25 ); }

		$this->rank_bonus = config::get( 'rankmod_badvalues' ); // value for badges level (elite, veteran, expert)
		if( !( $this->rank_bonus ) ) { for( $i=1;$i<=8;$i++ ) $this->rank_bonus[] = array( 300, 200, 100 ); }

		$this->rank_weap_badges = config::get( 'rankmod_weapreqs' ); // requirements for badges level (elite, veteran, expert)
		if( !( $this->rank_weap_badges ) ) { for( $i=1;$i<=6;$i++ ) $this->rank_weap_badges[] = array( 50, 25, 10 ); }

		$this->rank_weap_bonus = config::get( 'rankmod_weapvalues' ); // value for badges level (elite, veteran, expert)
		if( !( $this->rank_weap_bonus ) ) { for( $i=1;$i<=6;$i++ ) $this->rank_weap_bonus[] = array( 100, 50, 25 ); }

		$this->rank_sub_badges = config::get( 'rankmod_sub_badreqs' ); // requirements for badges level (elite, veteran, expert)
		if( !( $this->rank_sub_badges ) ) { for( $i=1;$i<=22;$i++ ) $this->rank_sub_badges[] = array( 50, 25, 10 ); }

		$this->rank_sub_bonus = config::get( 'rankmod_sub_badvalues' ); // value for badges level (elite, veteran, expert)
		if( !( $this->rank_sub_bonus ) ) { for( $i=1;$i<=22;$i++ ) $this->rank_sub_bonus[] = array( 300, 200, 100 ); }

		$this->rank_sub_enabled=config::get( 'rankmod_sub_enabled' ); // enabled sub classes
		if( !( $this->rank_sub_enabled ) ) { $this->rank_sub_enabled = "-assault-interceptor-covert-electronic-interdictor-hac-hactor-logistic-recon-t3-command-blackops-marauder-dread-carrier-mom-titan-barge-exhumer-transport-capindy-noob-"; }

		$this->rank_medal_bonus = config::get( 'rankmod_medal_bonus' ); // bonus for each awarded medal
		if( !( $this->rank_medal_bonus ) ) { $this->rank_medal_bonus = array( 200, 50, 100, 50, 50, 50, 50, 50, 50, 100, 200, 50 , 100, 200 ); }

		$this->rank_losermalus = config::get( 'rankmod_medal_losermalus' ); // count purple moon as a bonus or a malus

		$this->rank_show = config::get( 'rankmod_show' ); // Show images in the portrait (rank, medals, badges)
		if( !( $this->rank_show ) ) { $this->rank_show = "-rank-medal-nomeds-badge-progression-points-"; }

		/*$this->rank_known = config::get( 'rankmod_known' ); // Show Known Members Mod
		if( !( $this->rank_known ) ) { $this->rank_known = "-enabled-portrait-score-done-received-ratio-efficiency-last_seen-"; }*/

		$this->rank_active_awards = config::get( 'rankmod_activeawards' ); // Show Known Members Mod
		if( !( $this->rank_active_awards ) ) { $this->rank_active_awards = array( 1, 2, 3, 4, 5, 6, 7, 9 ); }

		$this->rank_last_update = config::get( 'rankmod_last_update' ); // gets last update of the medals table
		if( !( $this->rank_last_update ) ) {$this->rank_last_update='NEVER - Please run "check awards"'; }

		$this->rank_ttl = config::get( 'rankmod_titles' ); // titles array (array of arrays containing title,abbr,img,reqrp,reqkp)
		if( !( $this->rank_ttl ) ) { $this->rank_ttl = array( array( 'title' => 'Please SAVE SETTINGS first' ) );}

		$this->curr_kb_year = kbdate( 'Y' );
		$this->curr_kb_month = kbdate( 'm' ) - 1;
		if( $this->curr_kb_month == 0 )
		{
		  $this->curr_kb_month = 12;
		  $this->curr_kb_year--;
		}
	}

	function checkPreviousInstall()
	{
		if( !config::get( 'rankmod_sql_version' ) OR config::get( 'rankmod_sql_version' ) < 1 )
		{
			$this->message .= 'Pre 1.00 Installation found<br>';
			$this->message .= 'Purging old SQL tables and creating new ones...</b><br>';

			$this->sqlDropMedalsAssigned();
			$this->sqlDropMedalsTypes();
			$this->sqlCreateMedalsAssigned();
			$this->sqlCreateMedalsTypes();
			$this->sqlFillMedalsTypes();
			config::set( 'rankmod_sql_version', $this->rank_ver );

			$this->message .= '... done.<br>';
		}
		elseif( config::get( 'rankmod_sql_version' ) >= 1 && config::get( 'rankmod_sql_version' ) < $this->rank_ver )
		{
			$this->message .= 'Old ' . config::get( 'rankmod_sql_version' ). ' Installation found<br>';
			$this->message .= 'Commencing with Installation of RankMod ' . $this->rank_ver . '<br>';
			$this->message .= 'Purging awards and updating SQL table structures...<br>';

			$this->sqlDropMedalsAssigned();
			$this->sqlCreateMedalsAssigned();
			config::set( 'rankmod_sql_version', $this->rank_ver );

			$this->message .= '... done.<br><br>';
			$this->message .= '*** Please make sure you SAVE all admin pages ONCE so the mod works correctly! ***<br><br>';
		}
	}

	function checkViews()
	{
		if( isset( $this->viewList[$this->view] ) )
		{
			return call_user_func_array( $this->viewList[$this->view], array( &$this ) );
		}
		else
		{
			return call_user_func_array(  $this->viewList['rankmod_db_maintenance'], array( &$this ) );
		}
	}

	function menuSetup()
	{
		$this->addMenuItem( "caption","Rank Mod Admin");
		$this->addMenuItem( "link","1. DB maintenance", "?a=settings_rank_mod&view=rankmod_db_maintenance" );
		$this->addMenuItem( "link","2. Display Options", "?a=settings_rank_mod&view=rankmod_display_options" );
		$this->addMenuItem( "link","3. Medal Settings", "?a=settings_rank_mod&view=rankmod_medal_settings" );
		$this->addMenuItem( "link","4. Ribbon Settings", "?a=settings_rank_mod&view=rankmod_ribbon_settings" );
		$this->addMenuItem( "link","5. Rank Settings", "?a=settings_rank_mod&view=rankmod_rank_settings" );

		return;
	}

	function menu()
	{
		$menubox = new box("Admin Menu");
		$menubox->setIcon("menu-item.gif");
		foreach( $this->menuOptions as $options)
		{
			if(isset( $options[2]) )
				$menubox->addOption( $options[0],$options[1], $options[2]);
			else
				$menubox->addOption( $options[0],$options[1]);
		}
		return $menubox->generate();
	}

	function addMenuItem( $type, $name, $url = '' )
	{
		$this->menuOptions[] = array( $type, $name, $url);
	}

	function addView( $view, $callback )
	{
		$this->viewList[$view] = $callback;
	}

	function sqlDropMedalsAssigned()
	{
		$qry = new DBQuery();
		$query = 'DROP TABLE IF EXISTS `kb3_rank_medals_assigned`';
		$qry->execute( $query );
		unset( $qry );
	}

	function sqlDropMedalsTypes()
	{
		$qry = new DBQuery();
		$query = 'DROP TABLE IF EXISTS `kb3_rank_medals_types`';
		$qry->execute( $query );
		unset( $qry );
	}

	function sqlCreateMedalsAssigned()
	{
		$qry = new DBQuery();
		$query = 'CREATE TABLE IF NOT EXISTS `kb3_rank_medals_assigned` (
		`id` int(11) NOT NULL auto_increment,
		`med_site` varchar(16) NOT NULL,
		`plt_id` int(11) NOT NULL,
		`med_id` int(11) NOT NULL,
		`time_id` text NOT NULL,
		PRIMARY KEY  (`id`)
		)';
		$qry->execute( $query );
		unset( $qry );
	}

	function sqlCreateMedalsTypes()
	{
		$qry = new DBQuery();
		$query = 'CREATE TABLE IF NOT EXISTS `kb3_rank_medals_types` (
		`id` int(11) NOT NULL auto_increment,
		`name` varchar(255) NOT NULL,
		`title` varchar(255) NOT NULL,
		`description` varchar(255) NOT NULL,
		`filename` varchar(255) NOT NULL,
		`active` tinyint(1) NOT NULL,
  		`sorting` int(4) NOT NULL,
		PRIMARY KEY  (`id`)
		)';
		$qry->execute( $query );
		unset( $qry );
	}

	function sqlFillMedalsTypes()
	{
		$qry = new DBQuery();
		$query = sprintf(
		"INSERT INTO `kb3_rank_medals_types` (`id`, `name`, `title`, `description`, `filename`, `active`, `sorting`) VALUES
(1, 'Legion of Merit', 'Killer', 'most kills', 'killer', 1, 1),
(2, 'Navy Cross', 'Scorer', 'most killpoints', 'scorer', 1, 2),
(3, 'Navy Distinguished Service Medal', 'Solo Killer', 'most solo kills', 'solokiller', 1, 3),
(4, 'Defense Meritorious Service Medal', 'Damagedealer', 'most damage dealt', 'damagedealer', 1, 4),
(5, 'Joint Service Commendation Medal', 'Final Blows', 'most finishing blows', 'finalblows', 1, 5),
(6, 'Humanitarian Service Medal', 'Podkiller', 'most pods destroyed', 'podkiller', 1, 6),
(7, 'Military Outstanding Volunteer Service Medal', 'Griefer', 'most ruthless kills', 'griefer', 1, 7),
(8, 'Meritorious Service Medal', 'ISK Killer', 'most economocial damage caused', 'iskkiller', 0, 8),
(9, 'Purple Heart', 'Loser', 'most ships lost', 'loser', 1, 9),
(10, 'Joint Service Achievement Medal', 'Pirate', 'most lowsec kills', 'pirate', 0, 10),
(11, 'Distinguished Service Cross', 'Capkiller', 'most caps and supers killed', 'capitalkiller', 0, 11),
(12, 'Armed Forces Service Medal', 'Demolitions', 'most structures razed', 'demolitions', 0, 12),
(13, 'Global War on Terrorism Medal', 'Highsec enforcer', 'most kills in high sec systems', 'highseckiller', 0, 13),
(14, 'Prisoner of War Medal', 'Soft target', 'most ships lost in high sec systems', 'highsecloser', 0, 14)" );
		$qry->execute( $query );
		unset( $qry );
	}

	function sqlDeleteConfigBadgeRequirements()
	{
		$qry = new DBQuery();
		$query = sprintf(
		"DELETE FROM `kb3_config` WHERE CONVERT(`kb3_config`.`cfg_site` USING utf8) = '%s' AND CONVERT(`kb3_config`.`cfg_key` USING utf8) = 'rankmod_badreqs' LIMIT 1",
		KB_SITE  );
		$qry->execute( $query );

		$query = sprintf(
		"DELETE FROM `kb3_config` WHERE CONVERT(`kb3_config`.`cfg_site` USING utf8) = '%s' AND CONVERT(`kb3_config`.`cfg_key` USING utf8) = 'rankmod_badvalues' LIMIT 1",
		KB_SITE  );
		$qry->execute( $query );

		$query = sprintf(
		"DELETE FROM `kb3_config` WHERE CONVERT(`kb3_config`.`cfg_site` USING utf8) = '%s' AND CONVERT(`kb3_config`.`cfg_key` USING utf8) = 'rankmod_sub_badreqs' LIMIT 1",
		KB_SITE  );
		$qry->execute( $query );

		$query = sprintf(
		"DELETE FROM `kb3_config` WHERE CONVERT(`kb3_config`.`cfg_site` USING utf8) = '%s' AND CONVERT(`kb3_config`.`cfg_key` USING utf8) = 'rankmod_sub_badvalues' LIMIT 1",
		KB_SITE  );
		$qry->execute( $query );

		$query = sprintf(
		"DELETE FROM `kb3_config` WHERE CONVERT(`kb3_config`.`cfg_site` USING utf8) = '%s' AND CONVERT(`kb3_config`.`cfg_key` USING utf8) = 'rankmod_weapreqs' LIMIT 1",
		KB_SITE  );
		$qry->execute( $query );

		$query = sprintf(
		"DELETE FROM `kb3_config` WHERE CONVERT(`kb3_config`.`cfg_site` USING utf8) = '%s' AND CONVERT(`kb3_config`.`cfg_key` USING utf8) = 'rankmod_weapvalues' LIMIT 1",
		KB_SITE  );
		$qry->execute( $query );

		$query = sprintf(
		"DELETE FROM `kb3_config` WHERE CONVERT(`kb3_config`.`cfg_site` USING utf8) = '%s' AND CONVERT(`kb3_config`.`cfg_key` USING utf8) = 'rankmod_sub_enabled' LIMIT 1",
		KB_SITE  );
		$qry->execute( $query );
		unset( $qry );
	}

	function sqlDeleteConfigMedalSettings()
	{
		$qry = new DBQuery();
		$query = sprintf(
		"DELETE FROM `kb3_config` WHERE CONVERT(`kb3_config`.`cfg_site` USING utf8) = '%s' AND CONVERT(`kb3_config`.`cfg_key` USING utf8) = 'rankmod_medal_bonus' LIMIT 1",
		KB_SITE  );
		$qry->execute( $query );

		$query = sprintf(
		"DELETE FROM `kb3_config` WHERE CONVERT(`kb3_config`.`cfg_site` USING utf8) = '%s' AND CONVERT(`kb3_config`.`cfg_key` USING utf8) = 'rankmod_medal_losermalus' LIMIT 1",
		KB_SITE  );
		$qry->execute( $query );

		$query = sprintf(
		"DELETE FROM `kb3_config` WHERE CONVERT(`kb3_config`.`cfg_site` USING utf8) = '%s' AND CONVERT(`kb3_config`.`cfg_key` USING utf8) = 'rankmod_activeawards' LIMIT 1",
		KB_SITE  );
		$qry->execute( $query );
		unset( $qry );
	}

	function sqlDeleteConfigRankSettings()
	{
		$qry = new DBQuery();
		$query = sprintf(
		"DELETE FROM `kb3_config` WHERE CONVERT(`kb3_config`.`cfg_site` USING utf8) = '%s' AND CONVERT(`kb3_config`.`cfg_key` USING utf8) = '	rankmod_rtype' LIMIT 1",
		KB_SITE  );
		$qry->execute( $query );

		$query = sprintf(
		"DELETE FROM `kb3_config` WHERE CONVERT(`kb3_config`.`cfg_site` USING utf8) = '%s' AND CONVERT(`kb3_config`.`cfg_key` USING utf8) = 'rankmod_titles' LIMIT 1",
		KB_SITE  );
		$qry->execute( $query );

		$query = sprintf(
		"DELETE FROM `kb3_config` WHERE CONVERT(`kb3_config`.`cfg_site` USING utf8) = '%s' AND CONVERT(`kb3_config`.`cfg_key` USING utf8) = 'rankmod_titleset' LIMIT 1",
		KB_SITE  );
		$qry->execute( $query );

		$query = sprintf(
		"DELETE FROM `kb3_config` WHERE CONVERT(`kb3_config`.`cfg_site` USING utf8) = '%s' AND CONVERT(`kb3_config`.`cfg_key` USING utf8) = 'rankmod_imageset' LIMIT 1",
		KB_SITE  );
		$qry->execute( $query );

		$query = sprintf(
		"DELETE FROM `kb3_config` WHERE CONVERT(`kb3_config`.`cfg_site` USING utf8) = '%s' AND CONVERT(`kb3_config`.`cfg_key` USING utf8) = 'rankmod_convfactor' LIMIT 1",
		KB_SITE  );
		$qry->execute( $query );

		$query = sprintf(
		"DELETE FROM `kb3_config` WHERE CONVERT(`kb3_config`.`cfg_site` USING utf8) = '%s' AND CONVERT(`kb3_config`.`cfg_key` USING utf8) = 'rankmod_expbase' LIMIT 1",
		KB_SITE  );
		$qry->execute( $query );

		$query = sprintf(
		"DELETE FROM `kb3_config` WHERE CONVERT(`kb3_config`.`cfg_site` USING utf8) = '%s' AND CONVERT(`kb3_config`.`cfg_key` USING utf8) = 'rankmod_expfactor' LIMIT 1",
		KB_SITE  );
		$qry->execute( $query );
		unset( $qry );
	}

	public static function addViews( $home )
	{
		$home->addView( 'rankmod_db_maintenance', "RankModAdmin::viewDBMaintenance" );
		$home->addView( 'rankmod_display_options', "RankModAdmin::viewDisplayOptions" );
		$home->addView( 'rankmod_medal_settings', "RankModAdmin::viewMedalSettings" );
		$home->addView( 'rankmod_ribbon_settings', "RankModAdmin::viewRibbonSettings" );
		$home->addView( 'rankmod_rank_settings', "RankModAdmin::viewRankSettings" );
	}

	public static function viewDBMaintenance( $home )
	{
		global $smarty;

		include( 'settings_defines.php' );

		if( $_POST['drop_tabs'] )
		{
			config::set( 'rankmod_last_update', 0 );
			$nqry = new DBNormalQuery();
			$query = "DELETE FROM kb3_rank_medals_assigned WHERE med_site = '".KB_SITE."'";
			$nqry->execute( $query);

			$home->message .= 'Notice: medals and awards have been purged.';

			$home->initConfigVars();
		}

		if( $_POST['create_tabs'] )
		{
			$curr_kb_year = kbdate( 'Y' );
			$curr_kb_month = kbdate( 'm' ) - 1;
			if( $curr_kb_month == 0) {
			$curr_kb_month = 12;
			$curr_kb_year--;
			}
			$month = $_POST['kb_startm'];
			$year = $_POST['kb_starty'];
			if( $year==$curr_kb_year && $month>$curr_kb_month) {
			$message .= "<b>ERROR: </b><i>Wrong date, check start month!</i><br>";
			$message .= "<b>Tables NOT Created</b>";
			} elseif( $year>$curr_kb_year) {
			$message .= "<b>ERROR: </b><i>Wrong date, check start year!</i><br>";
			$message .= "<b>Tables NOT Created</b>";
			}
			else
			{
				$qry = new DBQuery();

				// if ranks have never meen updated, create new ranks table
				if( !config::get( 'rankmod_last_update' ) )
				{
					$query = 'CREATE TABLE IF NOT EXISTS `kb3_rank_medals_assigned` (
						`id` int(11) NOT NULL auto_increment,
						`med_site` varchar(16) NOT NULL,
						`plt_id` int(11) NOT NULL,
						`med_id` int(11) NOT NULL,
						`time_id` text NOT NULL,
						PRIMARY KEY  (`id`)
						)';
					$qry->execute( $query );
					$upd .= "".$curr_kb_year." - ".$curr_kb_month;
					config::set( 'rankmod_last_update',$upd);
				}
				// otherwise just delete the old rank data
				else
				{
					$nqry = new DBNormalQuery();
					$query = "DELETE FROM kb3_rank_medals_assigned WHERE med_site = '".KB_SITE."'";
					$nqry->execute( $query);
					$upd .= "".$curr_kb_year." - ".$curr_kb_month;
					config::set( 'rankmod_last_update',$upd);
				}

				// loop through kills and set awards
				while( $year <= $curr_kb_year )
				{
					while( ( $month <= $curr_kb_month && $year == $curr_kb_year ) || ( $month <= 12 && $year != $curr_kb_year ) )
					{
						if( $month < 10) { $p_month = "0".$month; } else { $p_month = $month; }
						$date = "".$year." - ".$p_month;

						$RankModAwards = new RankModAwards();
						$RankModAwards->month = $p_month;
						$RankModAwards->year = $year;

						$list = $RankModAwards->getTopKiller( $RankModAwards );
						if( $row = $list->getRow() )
						{
							RankModMedalsAssigned::saveAssignedMedal( $row['plt_id'], 1, $date, KB_SITE );
						}

						$list = $RankModAwards->getTopScorer( $RankModAwards );
						if( $row = $list->getRow() )
						{
							RankModMedalsAssigned::saveAssignedMedal( $row['plt_id'], 2, $date, KB_SITE );
						}

						$list = $RankModAwards->getTopSoloKiller( $RankModAwards );
						if( $row = $list->getRow() )
						{
							RankModMedalsAssigned::saveAssignedMedal( $row['plt_id'], 3, $date, KB_SITE );
						}

						$list = $RankModAwards->getTopDamagedealer( $RankModAwards );
						if( $row = $list->getRow() )
						{
							RankModMedalsAssigned::saveAssignedMedal( $row['plt_id'], 4, $date, KB_SITE );
						}

						$list = $RankModAwards->getTopFinalBlow( $RankModAwards );
						if( $row = $list->getRow() )
						{
							RankModMedalsAssigned::saveAssignedMedal( $row['plt_id'], 5, $date, KB_SITE );
						}

						$list = $RankModAwards->getTopPodKiller( $RankModAwards );
						if( $row = $list->getRow() )
						{
							RankModMedalsAssigned::saveAssignedMedal( $row['plt_id'], 6, $date, KB_SITE );
						}

						$list = $RankModAwards->getTopGriefer( $RankModAwards );
						if( $row = $list->getRow() )
						{
							RankModMedalsAssigned::saveAssignedMedal( $row['plt_id'], 7, $date, KB_SITE );
						}

						$list = $RankModAwards->getTopISKKiller( $RankModAwards );
						if( $row = $list->getRow() )
						{
							RankModMedalsAssigned::saveAssignedMedal( $row['plt_id'], 8, $date, KB_SITE );
						}

						$list = $RankModAwards->getTopLoser( $RankModAwards );
						if( $row = $list->getRow() )
						{
							RankModMedalsAssigned::saveAssignedMedal( $row['plt_id'], 9, $date, KB_SITE );
						}

						$list = $RankModAwards->getTopPirate( $RankModAwards );
						if( $row = $list->getRow() )
						{
							RankModMedalsAssigned::saveAssignedMedal( $row['plt_id'], 10, $date, KB_SITE );
						}

						$list = $RankModAwards->getTopCapitalKiller( $RankModAwards );
						if( $row = $list->getRow() )
						{
							RankModMedalsAssigned::saveAssignedMedal( $row['plt_id'], 11, $date, KB_SITE );
						}

						$list = $RankModAwards->getTopStructureKiller( $RankModAwards );
						if( $row = $list->getRow() )
						{
							RankModMedalsAssigned::saveAssignedMedal( $row['plt_id'], 12, $date, KB_SITE );
						}

						$list = $RankModAwards->getTopHighsec( $RankModAwards );
						if( $row = $list->getRow() )
						{
							RankModMedalsAssigned::saveAssignedMedal( $row['plt_id'], 13, $date, KB_SITE );
						}

						$list = $RankModAwards->getTopHighsecLoser( $RankModAwards );
						if( $row = $list->getRow() )
						{
							RankModMedalsAssigned::saveAssignedMedal( $row['plt_id'], 14, $date, KB_SITE );
						}

						$month++;
					}

					$year++;
					$month = 1;
				}
			}

			$home->message .= 'Alle medals and awards since ' . $_POST['kb_startm'] . '-' . $_POST['kb_starty'] . ' have been assigned.';

			$home->initConfigVars();
		}

		foreach( $kb_year as $key => $year )
		{
			$years[$key]['year'] = $year;
			if( $year == $home->curr_kb_year )
			{
				$years[$key]['selected'] = 1;
			}
		}
		foreach( $kb_month as $key => $month )
		{
			$months[$key]['month'] = $month;
			if( $month == $home->curr_kb_month )
			{
				$months[$key]['selected'] = 1;
			}
		}

		$smarty->assign( 'kb_years', $years );
		$smarty->assign( 'kb_months', $months );
		$smarty->assign( 'rankmod_last_update', $home->rank_last_update );

		$smarty->assign( 'actionmessage', $home->message );

		return $smarty->fetch( get_tpl( dirname( __FILE__ ) . '/' . 'settings_db_maintenance' ) );
	}

	public static function viewDisplayOptions( $home )
	{
		global $smarty;

		if( $_POST['submit'] )
		{
			// prepare rank show data
			$data .= "-";
			if( $_POST['r_ins']) {$data .="rank-";}
			if( $_POST['r_med']) {$data .="medal-";}
			if( $_POST['r_medrib']) {$data .="nomeds-";}
			if( $_POST['r_bad']) {$data .="badge-";}
			if( $_POST['r_case']) {$data .="progression-";}
			if( $_POST['rkd_base']) {$data .="points-";}
			config::set( 'rankmod_show', $data );

			$home->message .= 'Notice: Display options have been saved.';

			$home->initConfigVars();
		}

		if( strpos( $home->rank_show, "rank" ) )
		{
		    $options['show_insignia'] = 1;
		}

		if( strpos( $home->rank_show, "medal" ) )
		{
		    $options['show_medals'] = 1;
		}

		if( strpos( $home->rank_show, "nomeds" ) )
		{
		    $options['show_medalribbons'] = 1;
		}

		if( strpos( $home->rank_show, "badge" ) )
		{
		    $options['show_ribbons'] = 1;
		}

		if( strpos( $home->rank_show, "points" ) )
		{
		    $options['show_points'] = 1;
		}

		if( strpos( $home->rank_show, "progression" ) )
		{
		    $options['show_progression'] = 1;
		}

		$smarty->assign( 'options', $options );

		$smarty->assign( 'actionmessage', $home->message );

		return $smarty->fetch( get_tpl( dirname(__FILE__) . '/' . 'settings_display_options' ) );
	}

	public static function viewRibbonSettings( $home )
	{
		global $smarty;

		getShipRibbons( $shipbadges );
		getWeaponRibbons( $weaponbadges );

		if( $_POST['submit'] )
		{
			// set parent ship bonuses & requirements
			$r_badval = array();
			$r_badreq = array();
			$r_sub_badval = array();
			$r_sub_badreq = array();
			$data = "-";

			foreach( $shipbadges as $i => $ship )
			{
				if( $ship['parent'] !== null )
				{
					$class = $ship['type'];

					$r_sub_badreq[$ship['cnt']][0]=$_POST['rsbc_'.$i.'_elite'];
					$r_sub_badval[$ship['cnt']][0]=$_POST['rsbc_'.$i.'_belite'];
					$r_sub_badreq[$ship['cnt']][1]=$_POST['rsbc_'.$i.'_veteran'];
					$r_sub_badval[$ship['cnt']][1]=$_POST['rsbc_'.$i.'_bveteran'];
					$r_sub_badreq[$ship['cnt']][2]=$_POST['rsbc_'.$i.'_expert'];
					$r_sub_badval[$ship['cnt']][2]=$_POST['rsbc_'.$i.'_bexpert'];
					if( $_POST['enable_'.$i] )
					{
						$data .= $class . "-";
					}
				}
				else
				{
					$r_badreq[$ship['cnt']][0]=$_POST['rsc_'.$i.'_elite'];
					$r_badval[$ship['cnt']][0]=$_POST['rsc_'.$i.'_belite'];
					$r_badreq[$ship['cnt']][1]=$_POST['rsc_'.$i.'_veteran'];
					$r_badval[$ship['cnt']][1]=$_POST['rsc_'.$i.'_bveteran'];
					$r_badreq[$ship['cnt']][2]=$_POST['rsc_'.$i.'_expert'];
					$r_badval[$ship['cnt']][2]=$_POST['rsc_'.$i.'_bexpert'];
				}
			}
			config::set( 'rankmod_badreqs', $r_badreq);
			config::set( 'rankmod_badvalues', $r_badval);

			config::set( 'rankmod_sub_badreqs', $r_sub_badreq);
			config::set( 'rankmod_sub_badvalues', $r_sub_badval);
			config::set( 'rankmod_sub_enabled', $data);

			// set weapon bonuses & requirements
			$r_wbadval=array();
			$r_wbadreq=array();
			foreach( $weaponbadges as $i => $class )
			{
				$r_wbadreq[$i][0]=$_POST['rwr_'.$i.'_elite'];
				$r_wbadval[$i][0]=$_POST['rwr_'.$i.'_belite'];
				$r_wbadreq[$i][1]=$_POST['rwr_'.$i.'_veteran'];
				$r_wbadval[$i][1]=$_POST['rwr_'.$i.'_bveteran'];
				$r_wbadreq[$i][2]=$_POST['rwr_'.$i.'_expert'];
				$r_wbadval[$i][2]=$_POST['rwr_'.$i.'_bexpert'];
			}
			config::set( 'rankmod_weapreqs', $r_wbadreq );
			config::set( 'rankmod_weapvalues', $r_wbadval );

			$home->message .= 'Notice: Requirements, bonus points and active sub classes have been saved.';
			$home->initConfigVars();
		}
		elseif( $_POST['reset'] )
		{
			$home->sqlDeleteConfigBadgeRequirements();
			$home->message .= 'Notice: Ribbon settings were reset to defaults.';
			$home->initConfigVars();
		}

		foreach( $shipbadges as $i => $ship )
		{
			$classes = array( 0 => array( 'tag' => 'elite', 'desc' => 'Combat 1st Class' ), 1 => array( 'tag' => 'veteran', 'desc' => 'Combat 2nd Class' ), 2 => array( 'tag' => 'expert', 'desc' => 'Combat 3rd Class' )  );

			$ships[$i]['parent'] = $ship['parent'];
			$ships[$i]['type'] = $ship['type'];
			$ships[$i]['name'] = $ship['name'];

			if( $ship['type'] == 'kamikaze' ) { $ships[$i]['conj'] = 'like a'; } else { $ships[$i]['conj'] = 'in a'; }

			foreach( $classes as $j => $class )
			{
				if( !is_null( $ship['parent'] ) )
				{
					$ships[$i]['class'][$j]['requirement'] = $home->rank_sub_badges[$ship['cnt']][$j];
					$ships[$i]['class'][$j]['bonus'] = $home->rank_sub_bonus[$ship['cnt']][$j];
				}
				else
				{
					$ships[$i]['class'][$j]['requirement'] = $home->rank_badges[$ship['cnt']][$j];
					$ships[$i]['class'][$j]['bonus'] = $home->rank_bonus[$ship['cnt']][$j];
				}

				$ships[$i]['class'][$j]['desc'] = $class['desc'];
				$ships[$i]['class'][$j]['tag'] = $class['tag'];
				$ships[$i]['class'][$j]['tag2'] = ucfirst( $class['tag'] );
			}

			if( strpos( $home->rank_sub_enabled, $ships[$i]['type'] ) )
			{
				$ships[$i]['checked'] = 1;
			}
		}

		$smarty->assign( 'ship_badges', $ships );

		foreach( $weaponbadges as $i => $weapon )
		{
			$classes = array( 0 => array( 'tag' => 'elite', 'desc' => 'Master 1st Class' ), 1 => array( 'tag' => 'veteran', 'desc' => 'Master 2nd Class' ), 2 => array( 'tag' => 'expert', 'desc' => 'Master 3rd Class' )  );

			foreach( $classes as $j => $class )
			{
				$weapons[$i]['type'] = $weapon['type'];
				$weapons[$i]['name'] = $weapon['name'];

				$weapons[$i]['class'][$j]['requirement'] = $home->rank_weap_badges[$i][$j];
				$weapons[$i]['class'][$j]['bonus'] = $home->rank_weap_bonus[$i][$j];

				$weapons[$i]['class'][$j]['desc'] = $class['desc'];
				$weapons[$i]['class'][$j]['tag'] = $class['tag'];
				$weapons[$i]['class'][$j]['tag2'] = ucfirst( $class['tag'] );
			}
		}

		$smarty->assign( 'weapon_badges', $weapons );

		$smarty->assign( 'actionmessage', $home->message );

		return $smarty->fetch( get_tpl( dirname(__FILE__) . '/' . 'settings_ribbon_settings' ) );
	}

	public static function viewMedalSettings( $home )
	{
		global $smarty;

		if( $_GET['award_sort_up'] )
		{
			RankModMedalTypes::sortMedalUp( $_GET['award_sort_up'] );
			$message = 'Medal has been moved up';
		}
		elseif( $_GET['award_sort_down'] )
		{
			RankModMedalTypes::sortMedalDown( $_GET['award_sort_down'] );
			$message = 'Medal has been moved down';
		}

		if( $_POST['submit'] )
		{
			$medal_data = RankModMedalTypes::getMedals();

			if( count( $medal_data ) > 0 )
			{
				foreach( $medal_data as $i => $med )
				{
					$r_medval[$i]=$_POST['rm_'.$i];

					$RankModMedalTypes = new RankModMedalTypes( $med['medal_id'] );

					if( $_POST['award_active_'.$RankModMedalTypes->getId()] == 'on' )
					{
						$RankModMedalTypes->setStatus( 1 );
						$activeawards[] = $RankModMedalTypes->getId();
					}
					else
					{
						$RankModMedalTypes->setStatus( 0 );
					}

					$RankModMedalTypes->updateObject();

					$r_medval[$i] = $_POST['rm_'.$i];
				}
			}
			config::set( 'rankmod_medal_bonus', $r_medval );
			config::set( 'rankmod_activeawards', $activeawards );

			if( $_POST['pm_neg'] )
			{
			  config::set( 'rankmod_medal_losermalus', TRUE );
			}
			else
			{
			  config::set( 'rankmod_medal_losermalus', FALSE );
			}

			$home->message .= 'Medal values and sort order have been saved.';

			$home->initConfigVars();
		}
		elseif( $_POST['reset'] )
		{
			$home->sqlDeleteConfigMedalSettings();
			$home->message .= 'Notice: Medal settings were reset to defaults.';
			$home->initConfigVars();
		}

		$medal_data = RankModMedalTypes::getMedals();

		foreach( $medal_data as $i => $medal )
		{
			$medals[$i]['data'] = $medal;
			$medals[$i]['value'] = $home->rank_medal_bonus[$i];
		}

		$smarty->assign( 'medals', $medals );
		$smarty->assign( 'rank_losermalus', $home->rank_losermalus );

		$smarty->assign( 'actionmessage', $home->message );

		return $smarty->fetch( get_tpl( dirname(__FILE__) . '/' . 'settings_medal_settings' ) );
	}

	public static function viewRankSettings( $home )
	{
		global $smarty;

		include( 'settings_defines.php' );

		if( $_POST['submit'] )
		{
			config::set( 'rankmod_rtype', $_POST['r_group'] );
			config::set( 'rankmod_imageset', $_POST['r_imageset'] );
			config::set( 'rankmod_titleset', $_POST['r_titleset'] );

			config::set( 'rankmod_expfactor', $_POST['r_exp'] );
			config::set( 'rankmod_expbase', $_POST['r_base'] );
			config::set( 'rankmod_convfactor', $_POST['r_conv'] );

			$ensign_beginid = 0;
			$ensign_endid = ${$s_rank_specs[$_POST['r_titleset']]['title']}['typecount']['Enlisted'];
			$officer_beginid = ${$s_rank_specs[$_POST['r_titleset']]['title']}['typecount']['Enlisted'];
			$officer_endid = ${$s_rank_specs[$_POST['r_titleset']]['title']}['typecount']['Enlisted']+${$s_rank_specs[$_POST['r_titleset']]['title']}['typecount']['Officer'];

			switch( $_POST['r_group'] )
			{
				case "Enlisted": $a_s = $ensign_beginid; $a_l = $ensign_endid;
				break;
				case "Officer": $a_s = $ensign_endid; $a_l = $officer_endid;
				break;
				case "Enlisted + Officer": $a_s = $ensign_beginid; $a_l = $officer_endid;
				break;
			}
			#echo "<pre>";print_r(${$s_rank_specs[$_POST['r_titleset']]['title']}['titles']);exit;

			$ranklist = array();
			$blankimg = KB_HOST.'/mods/rank_mod/images/insignias/army_en0.png';
			$r = 0;
			$uniserv = 'enlisted';

			for( $i = $a_s; $i < $a_l; $i++ )
			{
				if( $i == $officer_beginid ) { $uniserv = 'officer'; }
				if( $uniserv == 'officer' ) { $m = $i - $officer_beginid; } else { $m = $i; }
				if( $_POST['k_title'] )
				{
					$ranktitle = $_POST['title_'.$r];
					$rankabbr = $_POST['abbr_'.$r];
				}
				else
				{
					$ranktitle = ${$s_rank_specs[$_POST['r_titleset']]['title']}['titles'][$i][0];
					$rankabbr = ${$s_rank_specs[$_POST['r_titleset']]['title']}['titles'][$i][1];
				}
				$imglink = 'insignias/'.$s_rank_specs[$_POST['r_imageset']][$uniserv].$m.'.png';
				$imgtemp = KB_HOST.'/mods/rank_mod/images/'.$imglink;
				$smarty->assign( 'img', $imgtemp );
				$smarty->assign( 'icon', $blankimg );
				$smarty->assign( 'name', $ranktitle );
				$img = $smarty->fetch( get_tpl( 'icon32' ) );
				$ranklist[]=array( 'title' => $ranktitle, 'abbr' => $rankabbr, 'img' => $img, 'reqrp' => 0, 'reqkp' => 0, 'imglink' => $imglink);
				$r++;
			}

			for( $i=0; $i<$r; $i++ )
			{
		    	$rps = ( $i * $_POST['r_base'] ) + round( $ranklist[$i-1]['reqrp'] * $_POST['r_exp'] );
		    	$kps = $rps * $_POST['r_conv'];
				$ranklist[$i]['reqrp'] = $rps;
				$ranklist[$i]['reqkp'] = $kps;
			}
			config::set( 'rankmod_titles', $ranklist);

			if( $_POST['k_title'] )
			{
				config::set( 'rankmod_keep',TRUE);
			}
			else
			{
				config::set( 'rankmod_keep',FALSE);
			}

			$home->initConfigVars();
		}
		elseif( $_POST['reset'] )
		{
			$home->sqlDeleteConfigRankSettings();

			$home->message .= 'Notice: Rank evolution settings have been reset to defaults.';

			$home->initConfigVars();
		}


		foreach( $s_rank_titleset as $key => $set )
		{
			$title_sets[$key]['set'] = $set;
			if( $set == $home->rank_titleset )
			{
				$title_sets[$key]['selected'] = 1;
			}
		}

		foreach( $s_rank_imageset as $key => $set )
		{
			$image_sets[$key]['set'] = $set;
			if( $set == $home->rank_imageset )
			{
				$image_sets[$key]['selected'] = 1;
			}
		}

		foreach( $s_rank_type as $key => $set )
		{
			$group_sets[$key]['set'] = $set;
			if( $set == $home->rank_type )
			{
				$group_sets[$key]['selected'] = 1;
			}
		}

		if( $home->keep_title ) { $words = 'Custom Rank Set'; } else { $words = $home->rank_titleset . " Rank Set"; }

		$smarty->assign( 'title_sets', $title_sets );
		$smarty->assign( 'image_sets', $image_sets );
		$smarty->assign( 'group_sets', $group_sets );
		$smarty->assign( 'rank_imageset', $home->rank_imageset );
		$smarty->assign( 'rank_type', $home->rank_type );
		$smarty->assign( 'keep_title', $home->keep_title );
		$smarty->assign( 'words', $words );
		$smarty->assign( 's_e_factor', $s_e_factor );
		$smarty->assign( 'rank_ef', $home->rank_ef );
		$smarty->assign( 'rank_base', $home->rank_base );
		$smarty->assign( 'rank_conv', $home->rank_conv );
		$smarty->assign( 'rank_ttl', $home->rank_ttl );

		$smarty->assign( 'actionmessage', $home->message );

		return $smarty->fetch( get_tpl( dirname(__FILE__) . '/' . 'settings_rank_settings' ) );
	}
}

$RankModAdmin = new RankModAdmin();
event::call( "rankmodAdmin_assembling", $RankModAdmin );
$html = $RankModAdmin->assemble();
$RankModAdmin->page->setContent( $html );

$RankModAdmin->context();
event::call("rankmodAdmin_context_assembling", $RankModAdmin);
$context = $RankModAdmin->assemble();
$RankModAdmin->page->addContext( $context);

$RankModAdmin->page->generate();
?>